==> enterprisemodules-wls_config-3.0.21.tar.gz: enterprisemodules-wls_config-3.0.21/lib/puppet/type/wls_foreign_server.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_foreign_server) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage foreign servers in a JMS Module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_foreign_server { 'jmsClusterModule:AQForeignServer':
          ensure                => 'present',
          defaulttargeting      => '1',
          extraproperties       => 'datasource=jdbc/hrDS',
          initialcontextfactory => ['oracle.jms.AQjmsInitialContextFactory'],
        }

    In this example you are managing a foreign server in the default domain. When you want to
    manage a foreign server in a specific domain, you can use:

        wls_foreign_server { 'my_domain/jmsClusterModule:Jboss':
          ensure                => 'present',
          connectionurl         => 'remote://10.10.10.10:4447',
          defaulttargeting      => '0',
          extraproperties       => ['java.naming.security.principal=jmsuser'],
          initialcontextfactory => 'org.jboss.naming.remote.client.InitialContextFactory',
          subdeployment         => 'wlsServers',
        }

    EOD

    bean_type('ForeignServer')
    bean_path('/JMSSystemResources/%{jmsmodule}/JMSResource/%{jmsmodule}/ForeignServers')

    ensurable
    parameter :domain
    parameter :name
    parameter :foreign_server_name
    parameter :jmsmodule
    parameter :timeout
    property  :password
    property  :subdeployment
    property  :defaulttargeting
    property  :extraproperties
    property  :initialcontextfactory
    property  :connectionurl
    extraproperties do
      property :connection_url
      property :default_targeting_enabled
      property :initial_context_factory
      property :jndi_properties_credential
      property :notes
      property :sub_deployment_name
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :foreign_server_name) do
      /(.+):(.+)/
    end
  end
end

==> enterprisemodules-wls_config-3.3.8.tar.gz: enterprisemodules-wls_config-3.3.8/lib/puppet/type/wls_foreign_server.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_foreign_server) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage foreign servers in a JMS Module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_foreign_server { 'jmsClusterModule:AQForeignServer':
          ensure                => 'present',
          defaulttargeting      => 1,
          extraproperties       => 'datasource=jdbc/hrDS',
          initialcontextfactory => ['oracle.jms.AQjmsInitialContextFactory'],
        }

    In this example you are managing a foreign server in the default domain. When you want to
    manage a foreign server in a specific domain, you can use:

        wls_foreign_server { 'my_domain/jmsClusterModule:Jboss':
          ensure                => 'present',
          connectionurl         => 'remote://10.10.10.10:4447',
          defaulttargeting      => '0',
          extraproperties       => ['java.naming.security.principal=jmsuser'],
          initialcontextfactory => 'org.jboss.naming.remote.client.InitialContextFactory',
          subdeployment         => 'wlsServers',
        }

    EOD

    bean_type('ForeignServer')
    bean_path('/JMSSystemResources/%{jmsmodule}/JMSResource/%{jmsmodule}/ForeignServers')

    ensurable
    parameter :domain
    parameter :name
    parameter :foreign_server_name
    parameter :jmsmodule
    parameter :timeout
    property  :password
    property  :subdeployment
    property  :defaulttargeting
    property  :extraproperties
    property  :initialcontextfactory
    property  :connectionurl
    extraproperties do
      property :connection_url
      property :default_targeting_enabled
      property :initial_context_factory
      property :jndi_properties_credential
      property :notes
      property :sub_deployment_name
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :foreign_server_name) do
      /(.+):(.+)/
    end
  end
end
